@@ -35,6 +35,7 @@ class PhContextFacade(object):
         self.upload_prefix = "upload"
 
     def execute(self):
+        ret = 0
         self.check_dir()
         if self.cmd == "create":
             self.command_create_exec()
@@ -45,10 +46,12 @@ class PhContextFacade(object):
         elif self.cmd == "dag":
             self.command_dag_exec()
         elif self.cmd == "submit":
-            self.command_submit_exec()
+            ret = self.command_submit_exec()
         else:
             self.command_publish_exec()
 
+        return ret
+
     def get_workspace_dir(self):
         return os.getenv('PH_WORKSPACE')
 
@@ -230,6 +233,7 @@ class PhContextFacade(object):
                 w.write(
                     line.replace("$alfred_command", str(jt.command)) \
                         .replace("$alfred_job_path", str(self.job_path[0:self.job_path.rindex("/") + 1]))
+                        .replace("$alfred_dag_owner", str(config.spec.owner)) \
                         .replace("$alfred_name", str(jt.name))
                 )
             subprocess.call(["cp", "-r",
@@ -269,7 +273,7 @@ class PhContextFacade(object):
         for it in args:
             if it != "":
                 cmd_arr.append(it)
-        subprocess.call(cmd_arr)
+        return subprocess.call(cmd_arr)
 
     def yaml2args(self, path):
         config = PhYAMLConfig(path)
